@@ -15,6 +15,7 @@
 #include "optionfrm.h"
 #include "vrslstfrm.h"
 #include <utilstr.h>
+#include <filemgr.h>
 
 //---------------------------------------------------------------------------
 #pragma resource "*.dfm"
@@ -96,6 +97,7 @@ char TForm1::CreateTextPane(SWModule *mod, char *font) {
 	newrtf->ScrollBars = ssVertical;
 	newrtf->ReadOnly = true;
 	newrtf->PopupMenu = (strcmp(mod->Name(), "N27U4")) ? PopupMenu2 : PopupMenu1;
+	newrtf->OnMouseDown = RTFMouseDown;
 
 	BuildRTFHeader(buf, font, 512);
 	newrtf->RTFHeader = buf;
@@ -137,6 +139,7 @@ char TForm1::CreateCommentPane(SWModule *mod) {
 		((SWDispRTF *)newrtf)->ScrollBars = ssVertical;
 		((SWDispRTF *)newrtf)->ReadOnly = true;
 		((SWDispRTF *)newrtf)->PopupMenu = PopupMenu2;
+		((SWDispRTF *)newrtf)->OnMouseDown = RTFMouseDown;
 	}
 
 	newtab->Caption = mod->Name();
@@ -161,6 +164,7 @@ char TForm1::CreateLDPane(SWModule *mod) {
 	newrtf->ScrollBars = ssVertical;
 	newrtf->ReadOnly = true;
 	newrtf->PopupMenu = PopupMenu2;
+	newrtf->OnMouseDown = RTFMouseDown;
 
 	mod->Disp(*displays.insert(displays.begin(), new RTFDisp(newrtf)));
 	mod->SetKey(DefaultStrKey);
@@ -289,12 +293,16 @@ void __fastcall TForm1::FormShow(TObject *Sender)
 	char *font;
 	int val;
 	int loop;
+	int maxFiles;
 	
 	logmodstate = true;
 	freshdict   = true;
 	if (SWLog::systemlog)
 		delete SWLog::systemlog;
 	SWLog::systemlog = new SWWinLog(this->Handle);		// set the system logger to our MSWindows specific SWLog class
+	if ((maxFiles = atoi(optionsconf->Sections["System"]["MaxFiles"].c_str()))) {
+		FileMgr::systemFileMgr.maxFiles = maxFiles;
+	}
 
 	DefaultVSKey = "Genesis 1:1";
 	cbBook->Clear();
@@ -647,7 +655,7 @@ void __fastcall TForm1::PopupMenuPopup(TObject *Sender)
 				char *buf = new char [ len + 1 ];
 				memset(buf, 0 , len + 1);
 				strncpy(buf, &rtf->Text.c_str()[versestart], len - 2);	// strip the # and | from the string
-				tmpVerseList = VerseKey::ParseVerseList(buf);
+				tmpVerseList = VerseKey::ParseVerseList(buf, DefaultVSKey);
 
 				ModMap::iterator target;
 				target = mainmgr->Modules.find(((TPageControl*)rtf->Parent->Parent)->ActivePage->Caption.c_str());
@@ -700,7 +708,7 @@ void __fastcall TForm1::createVerseList(TObject *Sender)
 void __fastcall TForm1::freeHandLookupKeyPress(TObject *Sender, char &Key)
 {
 	if (Key == '\r') {
-		SWListKey &tmpVerseList = VerseKey::ParseVerseList(freeHandLookup->Text.c_str());
+		SWListKey &tmpVerseList = VerseKey::ParseVerseList(freeHandLookup->Text.c_str(), DefaultVSKey);
 		if (tmpVerseList.Count() > 1) {
 			TVerseListFrm *tmpForm = new TVerseListFrm(this, tmpVerseList);
 			tmpForm->Caption = "User Verse List";
@@ -715,3 +723,10 @@ void __fastcall TForm1::freeHandLookupKeyPress(TObject *Sender, char &Key)
 }
 //---------------------------------------------------------------------------
 
+void __fastcall TForm1::RTFMouseDown(TObject *Sender, TMouseButton Button,
+	 TShiftState Shift, int X, int Y)
+{
+	((TWinControl *)Sender)->SetFocus();
+}
+//---------------------------------------------------------------------------
+
