@@ -186,6 +186,8 @@ __published:	// IDE-managed Components
 	void __fastcall PopupMenuPopup(TObject *Sender);
 	void __fastcall createVerseList(TObject *Sender);
 	void __fastcall freeHandLookupKeyPress(TObject *Sender, char &Key);
+	void __fastcall RTFMouseDown(TObject *Sender, TMouseButton Button,
+          TShiftState Shift, int X, int Y);
 private:	// User declarations
 	list <SWDisp *> displays;	// so we can delete each display we create
 	list <ModState *> modstates;
