@@ -99,7 +99,7 @@ struct abbrev VerseKey::abbrevs[] = {
 	{"1C", 46}, //   1 Corinthians
 	{"1CHRONICLES", 13}, //   1 Chronicles
 	{"1CORINTHIANS", 46}, //   1 Corinthians
-	{"1JOHN", 63}, //    1 John
+	{"1JOHN", 62}, //    1 John
 	{"1KINGS", 11   }, //    1 Kings
 	{"1PETER", 60   }, //    1 Peter
 	{"1SAMUEL", 9   }, //    1 Samuel
@@ -107,20 +107,20 @@ struct abbrev VerseKey::abbrevs[] = {
 	{"1TIMOTHY", 54   }, //   1 Timothy
 	{"2 C", 47   }, //   2 Corinthians
 	{"2 CHRONICLES", 14   }, //   2 Chronicles
-	{"2 CORINTHANS", 47   }, //   2 Corinthians
+	{"2 CORINTHIANS", 47   }, //   2 Corinthians
 	{"2 JOHN", 63   }, //    2 John
 	{"2 KINGS", 12   }, //    2 Kings
 	{"2 PETER", 61   }, //    2 Peter
-	{"2 SAMUEL", 8   }, //    2 Samuel
+	{"2 SAMUEL", 10   }, //    2 Samuel
 	{"2 THESSALONIANS", 53   }, //   2 Thessalonians
 	{"2 TIMOTHY", 55   }, //   2 Timothy
 	{"2C", 47   }, //   2 Corinthians
 	{"2CHRONICLES", 14   }, //   2 Chronicles
-	{"2CORINTHANS", 47   }, //   2 Corinthians
+	{"2CORINTHIANS", 47   }, //   2 Corinthians
 	{"2JOHN", 63   }, //    2 John
 	{"2KINGS", 12   }, //    2 Kings
 	{"2PETER", 61   }, //    2 Peter
-	{"2SAMUEL", 8   }, //    2 Samuel
+	{"2SAMUEL", 10   }, //    2 Samuel
 	{"2THESSALONIANS", 53   }, //   2 Thessalonians
 	{"2TIMOTHY", 55   }, //   2 Timothy
 	{"3 JOHN", 64   }, //    3 John
@@ -163,7 +163,7 @@ struct abbrev VerseKey::abbrevs[] = {
 	{"ICORINTHIANS", 46}, //   1 Corinthians
 	{"II C", 47   }, //   2 Corinthians
 	{"II CHRONICLES", 14   }, //   2 Chronicles
-	{"II CORINTHANS", 47   }, //   2 Corinthians
+	{"II CORINTHIANS", 47   }, //   2 Corinthians
 	{"II JOHN", 63   }, //    2 John
 	{"II KINGS", 12   }, //    2 Kings
 	{"II PETER", 61   }, //    2 Peter
@@ -173,7 +173,7 @@ struct abbrev VerseKey::abbrevs[] = {
 	{"IIIJOHN", 64   }, //    3 John
 	{"IIC", 47   }, //   2 Corinthians
 	{"IICHRONICLES", 14   }, //   2 Chronicles
-	{"IICORINTHANS", 47   }, //   2 Corinthians
+	{"IICORINTHIANS", 47   }, //   2 Corinthians
 	{"III JOHN", 64   }, //    3 John
 	{"IIJOHN", 63   }, //    2 John
 	{"IIKINGS", 12   }, //    2 Kings
@@ -199,7 +199,7 @@ struct abbrev VerseKey::abbrevs[] = {
 	{"JOHN", 43   }, //   John
 	{"JONAH", 32   }, //   Jonah
 	{"JOSHUA", 6   }, //   Joshua
-	{"JUD", 9   }, //   Judges
+	{"JUD", 7   }, //   Judges
 	{"JUDE", 65   }, //  Jude
 	{"JUDGES", 7}, //  Judges
 	{"L", 42}, //     Luke
@@ -210,7 +210,7 @@ struct abbrev VerseKey::abbrevs[] = {
 	{"MA", 40}, //    Matthew
 	{"MALACHI", 39   }, //   Malachi
 	{"MARK", 41}, //   Mark
-	{"MATTHEW", 50}, //   Matthew
+	{"MATTHEW", 40}, //   Matthew
 	{"MICAH", 33}, //    Micah
 	{"MK", 41}, //    Mark
 	{"MR", 41}, //    Mark
@@ -228,13 +228,13 @@ struct abbrev VerseKey::abbrevs[] = {
 	{"PHP", 50}, //   Philippians
 	{"PSALMS", 19}, //    Psalms
 	{"PROVERBS", 20}, //    Proverbs
-	{"REVELATION", 66}, //     Revelation
+	{"REVELATION OF JOHN", 66}, //     Revelation
 	{"ROMANS", 45}, //    Romans
 	{"RUTH", 8}, //    Ruth
 	{"SONG OF SOLOMON", 22}, //     Song of Solomon
 	{"SONG OF SONGS", 22}, //     Song of Solomon
 	{"TITUS", 56}, //     Titus
-	{"ZECARIAH", 38}, //   Zechariah
+	{"ZECHARIAH", 38}, //   Zechariah
 	{"ZEPHANIAH", 36}, //   Zephaniah
 	{"", -1} //   Zephaniah
 };
