@@ -8,16 +8,18 @@
 #ifndef RAWVERSE_H
 #define RAWVERSE_H
 
+#include <filemgr.h>
+
 class RawVerse {
 	static int instance;	// number of instantiated RawVerse objects or derivitives
-	int idxfp[2];
-	int textfp[2];
+	FileDesc *idxfp[2];
+	FileDesc *textfp[2];
 	char *path;
 
 protected:
-	void findoffset(char testmt, long idxoff, long *start, short *end);
+	void findoffset(char testmt, long idxoff, long *start, unsigned short *end);
 	void preptext(char *buf);
-	void gettext(char testmt, long start, short size, char *buf);
+	void gettext(char testmt, long start, unsigned short size, char *buf);
 	
 public:
 	char nl;
