@@ -19,8 +19,9 @@ public:
 	SWListKey(const char *ikey = 0);
 	virtual ~SWListKey();
 
-	virtual void ClearList();
+	virtual void ClearList();	// delete all elements
 	virtual int Count();
+	virtual void Remove();	// remove current element
 	virtual char SetToElement(int);
 	virtual SWListKey &operator <<(SWKey &); // add to list
 	virtual SWListKey &operator =(SWListKey &ikey);
