@@ -77,7 +77,7 @@ public:
 	virtual char Headings(char iheadings = MAXPOS(char));
 	virtual long Index(long iindex = MAXPOS(long));
 
-	static SWListKey &ParseVerseList(char *);
+	static SWListKey &ParseVerseList(char *buf, const char *defaultKey = "Genesis 1:1");
 
 	virtual char operator ==(SWKey &ikey);
 	virtual char operator  >(SWKey &ikey);
