@@ -181,7 +181,7 @@ int VerseKey::getBookAbbrev(char *abbr)
  * RET:	ListKey reference filled with verse entries contained in buf
  */
 
-SWListKey &VerseKey::ParseVerseList(char *buf)
+SWListKey &VerseKey::ParseVerseList(char *buf, const char *defaultKey)
 {
 	SWKey textkey;
 
@@ -198,9 +198,11 @@ SWListKey &VerseKey::ParseVerseList(char *buf)
 	int loop;
 	char comma = 0;
 	char dash = 0;
+	SWListKey tmpListKey;
+	SWKey tmpDefaultKey = defaultKey;
 
-	internalListKey.ClearList();
-
+	tmpListKey << tmpDefaultKey;
+	
 	while (*buf) {
 		switch (*buf) {
 		case ':':
@@ -227,9 +229,19 @@ SWListKey &VerseKey::ParseVerseList(char *buf)
 			bookno = -1;
 			if (*book) {
 				for (loop = strlen(book) - 1; loop+1; loop--) {
-					if ((isdigit(book[loop])) || (book[loop] == ' '))
+					if ((isdigit(book[loop])) || (book[loop] == ' ')) {
 						book[loop] = 0;
-					else	break;
+						continue;
+					}
+					else {
+						if ((toupper(book[loop])=='F')&&(loop)) {
+							if ((isdigit(book[loop-1])) || (book[loop-1] == ' ') || (toupper(book[loop-1]) == 'F')) {
+								book[loop] = 0;
+								continue;
+							}
+						}
+					}
+					break;
 				}
 				bookno = getBookAbbrev(book);
 			}
@@ -239,16 +251,16 @@ SWListKey &VerseKey::ParseVerseList(char *buf)
 				curkey.Book(1);
 
 				if (bookno < 0) {
-					curkey.Testament(VerseKey(internalListKey).Testament());
-					curkey.Book(VerseKey(internalListKey).Book());
+					curkey.Testament(VerseKey(tmpListKey).Testament());
+					curkey.Book(VerseKey(tmpListKey).Book());
 				}
 				else {
 					curkey.Testament(1);
 					curkey.Book(bookno);
 				}
 
-				if (comma) {
-					curkey.Chapter(VerseKey(internalListKey).Chapter());
+				if ((comma)||((verse < 0)&&(bookno < 0))) {
+					curkey.Chapter(VerseKey(tmpListKey).Chapter());
 					curkey.Verse(chap);  // chap because this is the first number captured
 				}
 				else {
@@ -257,7 +269,7 @@ SWListKey &VerseKey::ParseVerseList(char *buf)
 				}
 
 				if (!dash)
-					internalListKey << curkey;
+					tmpListKey << curkey;
 			}
 			*book = 0;
 			chap = -1;
@@ -270,16 +282,27 @@ SWListKey &VerseKey::ParseVerseList(char *buf)
 			else	dash = 0;
 			break;
 		case 10:	// ignore these
-		case 13: break;
+		case 13: 
+		case '.':
+			break;
 		default:
 			if (isdigit(*buf)) {
 				number[tonumber++] = *buf;
 			}
 			else {
-				number[tonumber] = 0;
-				tonumber = 0;
+				switch (*buf) {
+				case ' ':    // ignore these and don't reset number
+				case 'f':
+				case 'F':
+					break;
+				default:
+					number[tonumber] = 0;
+					tonumber = 0;
+					break;
+				}
 			}
-			book[tobook++] = toupper(*buf);
+			if (chap == -1)
+				book[tobook++] = toupper(*buf);
 		}
 		lastchar = *buf;
 		buf++;
@@ -296,9 +319,19 @@ SWListKey &VerseKey::ParseVerseList(char *buf)
 	tobook = 0;
 	if (*book) {
 		for (loop = strlen(book) - 1; loop+1; loop--) {
-			if ((isdigit(book[loop])) || (book[loop] == ' '))
+			if ((isdigit(book[loop])) || (book[loop] == ' ')) {
 				book[loop] = 0;
-			else	break;
+				continue;
+			}
+			else {
+				if ((toupper(book[loop])=='F')&&(loop)) {
+					if ((isdigit(book[loop-1])) || (book[loop-1] == ' ') || (toupper(book[loop-1]) == 'F')) {
+						book[loop] = 0;
+						continue;
+					}
+				}
+			}
+			break;
 		}
 		bookno = getBookAbbrev(book);
 	}
@@ -308,16 +341,16 @@ SWListKey &VerseKey::ParseVerseList(char *buf)
 		curkey.Book(1);
 
 		if (bookno < 0) {
-			curkey.Testament(VerseKey(internalListKey).Testament());
-			curkey.Book(VerseKey(internalListKey).Book());
+			curkey.Testament(VerseKey(tmpListKey).Testament());
+			curkey.Book(VerseKey(tmpListKey).Book());
 		}
 		else {
 			curkey.Testament(1);
 			curkey.Book(bookno);
 		}
 
-		if (comma) {
-			curkey.Chapter(VerseKey(internalListKey).Chapter());
+		if ((comma)||((verse < 0)&&(bookno < 0))) {
+			curkey.Chapter(VerseKey(tmpListKey).Chapter());
 			curkey.Verse(chap);  // chap because this is the first number captured
 		}
 		else {
@@ -326,10 +359,12 @@ SWListKey &VerseKey::ParseVerseList(char *buf)
 		}
 
 		if (!dash)
-			internalListKey << curkey;
+			tmpListKey << curkey;
 	}
 	*book = 0;
-
+	tmpListKey = TOP;
+	tmpListKey.Remove();	// remove defaultKey
+	internalListKey = tmpListKey;
 	internalListKey = TOP;	// Align internalListKey to first element before passing back;
 
 	return internalListKey;
